======================================
Welcome to kafka-tools' Documentation!
======================================

kafka-tools is a collection of various tools for managing Apache Kafka.

.. toctree::
   :maxdepth: 2

   getting_started
   commands
   contributing

API Documentation
=================

.. toctree::
   :maxdepth: 1

   tools/index
   tools/assigner/index
   tools/protocol/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
